$darcs_patches = [
                   {
                     'hash' => '20071024174843-178ae-9bdbc4f381783eb4e5120f5607095844412d824e.gz',
                     'inverted' => 'False',
                     'date' => '20071024174843',
                     'name' => [
                               'First test version'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Wed Oct 24 10:48:43 PDT 2007'
                   },
                   {
                     'hash' => '20071024174904-178ae-f083319198aa734dc7e85d12a5383439effc0cf8.gz',
                     'inverted' => 'False',
                     'date' => '20071024174904',
                     'name' => [
                               'First working version.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Wed Oct 24 10:49:04 PDT 2007'
                   },
                   {
                     'hash' => '20071024175149-178ae-9ae177f263bd5f83575311d9e5883003cc3a085e.gz',
                     'inverted' => 'False',
                     'date' => '20071024175149',
                     'name' => [
                               'Better error message when time doesn\'t parse.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Wed Oct 24 10:51:49 PDT 2007'
                   },
                   {
                     'hash' => '20071024175208-178ae-4dd905b27c571a4ea512f532c19dbee138f0b587.gz',
                     'inverted' => 'False',
                     'date' => '20071024175208',
                     'name' => [
                               'Better error message when there are 2 patches with the same date.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Wed Oct 24 10:52:08 PDT 2007'
                   },
                   {
                     'hash' => '20071024190103-178ae-d212a0a94dab0262d19bd612dc5121e17237f7c4.gz',
                     'inverted' => 'False',
                     'date' => '20071024190103',
                     'name' => [
                               'Disambiguate patches with the same date by looking in the .gz.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Wed Oct 24 12:01:03 PDT 2007'
                   },
                   {
                     'hash' => '20071024190231-178ae-778eca584d1d2bf5762a789e29508f7e5be24fc7.gz',
                     'inverted' => 'False',
                     'date' => '20071024190231',
                     'name' => [
                               'Add support for UNDO patches.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Wed Oct 24 12:02:31 PDT 2007'
                   },
                   {
                     'hash' => '20081222020535-c490e-1731b8513ed35df2be3907523f74aa8a8998f57c.gz',
                     'comment' => [
                                  'Ignore-this: b0d54add2c9729dbc8484b27cbb21807'
                                ],
                     'inverted' => 'False',
                     'date' => '20081222020535',
                     'name' => [
                               'Stop printing ugly new "Ignore-this" lines.'
                             ],
                     'author' => 'David Caldwell <david@porkrind.org>',
                     'local_date' => 'Sun Dec 21 18:05:35 PST 2008'
                   },
                   {
                     'hash' => '20081222084223-c490e-f8fbd642369a4bac6acdac6aa90491205655415a.gz',
                     'comment' => [
                                  'Ignore-this: a2a879005561f4e8db4d396fa480ef04'
                                ],
                     'inverted' => 'False',
                     'date' => '20081222084223',
                     'name' => [
                               'Move some stuff around to make it more logical.'
                             ],
                     'author' => 'David Caldwell <david@porkrind.org>',
                     'local_date' => 'Mon Dec 22 00:42:23 PST 2008'
                   },
                   {
                     'hash' => '20081222085948-c490e-3e15f936533c9ae3467cfaab5daca93f3b3c0526.gz',
                     'comment' => [
                                  'Ignore-this: 7778b85acac4694235d890c8ad1959e7'
                                ],
                     'inverted' => 'False',
                     'date' => '20081222085948',
                     'name' => [
                               'Move the old inventory inside a third-party/darcs-notify/ directory.'
                             ],
                     'author' => 'David Caldwell <david@porkrind.org>',
                     'local_date' => 'Mon Dec 22 00:59:48 PST 2008'
                   },
                   {
                     'hash' => '20081224214759-c490e-c3b248f26edaecd337987fe7e6c4614d0cdacc17.gz',
                     'comment' => [
                                  'Ignore-this: 30ce226b8789ed44252e6f06e177d51'
                                ],
                     'inverted' => 'False',
                     'date' => '20081224214759',
                     'name' => [
                               'Fix typo in documentation so I don\'t look as stupid as I actually am.'
                             ],
                     'author' => 'David Caldwell <david@porkrind.org>',
                     'local_date' => 'Wed Dec 24 13:47:59 PST 2008'
                   },
                   {
                     'hash' => '20081224215056-c490e-95b924fb5e9ef05a8f49aea856a23eeb4412ac38.gz',
                     'comment' => [
                                  'Ignore-this: 28bb2b40ed7e621de2660558ca8abb4d'
                                ],
                     'inverted' => 'False',
                     'date' => '20081224215056',
                     'name' => [
                               'Better explain X-Darcs-Notify.'
                             ],
                     'author' => 'David Caldwell <david@porkrind.org>',
                     'local_date' => 'Wed Dec 24 13:50:56 PST 2008'
                   }
                 ];
