$darcs_patches = [
                   {
                     'hash' => '20071028080935-178ae-d4cc07a0319d5374a337410200ca170940df32ea.gz',
                     'inverted' => 'False',
                     'date' => '20071028080935',
                     'name' => [
                               '[blah/blahc] Original blah blah c blah.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Sun Oct 28 01:09:35 PDT 2007'
                   },
                   {
                     'hash' => '20071028082936-178ae-48e703a23d9c4a8372bcca9699bb2eb222d15e26.gz',
                     'inverted' => 'True',
                     'date' => '20071028082936',
                     'name' => [
                               '[lib/blah.c] Eat trailing space as well as tabs on the end of a line since blah loves to give them to us.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Sun Oct 28 01:29:36 PDT 2007'
                   },
                   {
                     'hash' => '20071028085156-178ae-8f3f689798f4a78e0b7d11ff35dad8517615eda4.gz',
                     'inverted' => 'False',
                     'date' => '20071028085156',
                     'name' => [
                               '[lib/blah.c] Make BLAH name mismatches non-fatal since blah can\'t seem to give us BLAHs that match.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Sun Oct 28 01:51:56 PDT 2007'
                   },
                   {
                     'hash' => '20071028114343-178ae-e4c6e4aa8dc0866926a93d55e3597d89e4aadaff.gz',
                     'inverted' => 'False',
                     'date' => '20071028114343',
                     'name' => [
                               '[position] replace dangerous while loop normalization (previously hung threads on NaN with -ffast-math!)'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Sun Oct 28 04:43:43 PDT 2007'
                   },
                   {
                     'hash' => '20071021003818-178ae-4cb26773d1e5ab577b399bebe0c4c4b0b48a3105.gz',
                     'comment' => [
                                  'So you can find them, so they\'re colored, and so you can use them in drawer sets.'
                                ],
                     'inverted' => 'False',
                     'date' => '20071021003818',
                     'name' => [
                               '[blah/blah.c] Move label toggles into drawers.'
                             ],
                     'author' => 'David Caldwell <david@example.com>',
                     'local_date' => 'Sat Oct 20 17:38:18 PDT 2007'
                   }
                 ];
